@@ -4,7 +4,7 @@ use 5.008001;
 use strict;
 use warnings;
 
-our $VERSION = '1.11';
+our $VERSION = '1.12';
 
 use version;
 use JSON 2;
@@ -31,15 +31,23 @@ sub new {
     my $self = bless {
         opt  => \@opt,
         json => JSON->new,
+        awscli_path => $param{awscli_path} // 'aws',
     }, $class;
 
     return $self;
 }
 
+sub awscli_path {
+    my ($self) = @_;
+    return $self->{awscli_path};
+}
+
 sub awscli_version {
+    my ($self) = @_;
     unless (defined $AWSCLI_VERSION) {
         $AWSCLI_VERSION = do {
-            my $vs = qx(aws --version 2>&1) || '';
+            my $awscli_path = $self->awscli_path;
+            my $vs = qx($awscli_path --version 2>&1) || '';
             my $v;
             if ($vs =~ m{/([0-9.]+)\s}) {
                 $v = $1;
@@ -124,7 +132,7 @@ sub _execute {
     my $self    = shift;
     my $service = shift;
     my $operation = shift;
-    my @cmd = ('aws', @{$self->{opt}}, $service, $operation);
+    my @cmd = ($self->awscli_path, @{$self->{opt}}, $service, $operation);
     if ($service eq 'ec2' && $operation eq 'wait') {
         push(@cmd, shift @_);
     }
@@ -138,7 +146,7 @@ sub _execute {
         # compat: ec2 run-instances
         # >= 0.14.0 : --count N or --count MIN:MAX
         # <  0.14.0 : --min-count N and --max-count N
-        if (__PACKAGE__->awscli_version >= 0.14.0) {
+        if ($self->awscli_version >= 0.14.0) {
             my($min,$max) = (1,1);
             for my $hk (keys %$param) {
                 if ($hk eq 'min_count') {
@@ -160,11 +168,11 @@ sub _execute {
             $param->{min_count} = $min unless $param->{min_count};
             $param->{max_count} = $max unless $param->{max_count};
         }
-    } elsif ($service eq 's3' && __PACKAGE__->awscli_version >= 0.15.0) {
+    } elsif ($service eq 's3' && $self->awscli_version >= 0.15.0) {
         if ($operation !~ /^(?:cp|ls|mb|mv|rb|rm|sync|website)$/) {
             return $self->s3api($operation, @_);
         }
-    } elsif ($service eq 's3api' && __PACKAGE__->awscli_version < 0.15.0) {
+    } elsif ($service eq 's3api' && $self->awscli_version < 0.15.0) {
         return $self->s3($operation, @_);
     }
 
